==> camel-saxon-2.12.2-sources.jar: org/apache/camel/component/xquery/XQueryModuleURIResolver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xquery;

import javax.xml.transform.stream.StreamSource;

import net.sf.saxon.lib.ModuleURIResolver;
import net.sf.saxon.trans.XPathException;

/**
 * Resolves XQuery file imports
 */
public class XQueryModuleURIResolver implements ModuleURIResolver {
    private static final long serialVersionUID = 1L;

    private final XQueryComponent xqueryComponent;

    public XQueryModuleURIResolver(XQueryComponent xqueryComponent) {
        this.xqueryComponent = xqueryComponent;
    }

    public StreamSource[] resolve(String moduleURI, String baseURI, String[] locations) throws XPathException {
        StreamSource[] ss = new StreamSource[locations.length];
        try {
            for (int i = 0; i < locations.length; i++) {
                ss[i] = new StreamSource(xqueryComponent.resolveModuleResource(locations[i]).openStream());
            }
        } catch (Exception e) {
            throw new XPathException("Error resolving resource: " + locations, e);
        }
        return ss;
    }

}

==> camel-saxon-2.16.5-sources.jar: org/apache/camel/component/xquery/XQueryModuleURIResolver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xquery;

import java.util.Arrays;

import javax.xml.transform.stream.StreamSource;

import net.sf.saxon.lib.ModuleURIResolver;
import net.sf.saxon.trans.XPathException;

/**
 * Resolves XQuery file imports
 */
public class XQueryModuleURIResolver implements ModuleURIResolver {
    private static final long serialVersionUID = 1L;

    private final XQueryComponent xqueryComponent;

    public XQueryModuleURIResolver(XQueryComponent xqueryComponent) {
        this.xqueryComponent = xqueryComponent;
    }

    public StreamSource[] resolve(String moduleURI, String baseURI, String[] locations) throws XPathException {
        StreamSource[] ss = new StreamSource[locations.length];
        try {
            for (int i = 0; i < locations.length; i++) {
                ss[i] = new StreamSource(xqueryComponent.resolveModuleResource(locations[i]).openStream());
            }
        } catch (Exception e) {
            throw new XPathException("Error resolving resource: " + Arrays.toString(locations), e);
        }
        return ss;
    }

}
